==> fshows-sdk-core-1.0.0.20231225-20231227.030249-1-sources.jar: com/fshows/sdk/core/client/tempalte/nest/NestTemplateApiClinet.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package
        com.fshows.sdk.core.client.tempalte.nest;

import com.fshows.sdk.core.client.base.AbstractApiClient;
import com.fshows.sdk.core.client.base.handler.IHttpRequestHandler;
import com.fshows.sdk.core.client.base.model.ApiRequestModel;
import com.fshows.sdk.core.client.base.model.ApiResponseModel;
import com.fshows.sdk.core.client.base.model.ClientInfoModel;
import com.fshows.sdk.core.client.base.model.DefaultClientConfigModel;
import com.fshows.sdk.core.client.base.model.DefaultRequestContext;
import com.fshows.sdk.core.client.base.definition.IApiDefinition;
import com.fshows.sdk.core.client.base.handler.IApiSignHandler;
import com.fshows.sdk.core.client.base.handler.ISerializableHandler;
import com.fshows.sdk.core.client.component.http.PostHttpRequestHandler;
import com.fshows.sdk.core.client.tempalte.nest.apienum.NestApiDefinitionEnum;
import com.fshows.sdk.core.client.tempalte.nest.request.NestBaseRequest;
import com.fshows.sdk.core.client.tempalte.nest.request.NestBizRequest;
import com.fshows.sdk.core.client.tempalte.nest.response.NestBaseResponse;
import com.fshows.sdk.core.client.component.serializable.JsonSerializableHandler;
import com.fshows.sdk.core.client.component.signer.RsaSignHandlerImpl;
import com.fshows.sdk.core.exception.FsApiException;
import com.fshows.sdk.core.util.RequestParamUtils;

import java.io.IOException;

/**
 * 嵌套参数客户端模版
 * @author liluqing
 * @version NestTemplateApiClinet.java, v 0.1 2023-12-12 15:40
 */
public class NestTemplateApiClinet extends AbstractApiClient<NestBizRequest, NestBaseResponse, NestApiDefinitionEnum> {

     /**
      * 加签验签处理器
      */
    protected IApiSignHandler iApiSignHandler = new RsaSignHandlerImpl();

     /**
      * 序列化处理器
      */
     protected ISerializableHandler paramSerializable = new JsonSerializableHandler();

     /**
      * 请求执行器
      */
     protected IHttpRequestHandler httpRequestHandler = new PostHttpRequestHandler();

    public NestTemplateApiClinet(DefaultClientConfigModel apiClientConfig) throws FsApiException {
        super(apiClientConfig);
    }

     /**
      * 构建请求参数
      *
      * @param request
      * @param context
      * @return
      */
    @Override
    protected ApiRequestModel buildApiRequestModel(NestBizRequest request, DefaultRequestContext context) {
        // todo: 一般来说该方法需要完成以下事项
        // 1. 设置网关地址  2. 请求参数填充  3. 请求加签  4. 请求参数序列化

        // sdk客户端配置
        DefaultClientConfigModel defaultClientConfigModel = context.getApiClientConfig();

        ApiRequestModel apiRequestModel = new ApiRequestModel();
        // 设置网关地址
        apiRequestModel.setApiURL(context.getApiClientConfig().getApiParentURL() + context.getIApiDefinition().getApiURI());
        // 请求加签处理
        apiRequestModel.setParamMap(RequestParamUtils.toMapObj(request, apiClientConfig.isHump()));
        apiRequestModel.setRequestSign(iApiSignHandler.sign(apiRequestModel, context));

        // 补充参数构建实际的请求入参
        NestBaseRequest nestBaseRequest = new NestBaseRequest();
        nestBaseRequest.setMchntCd(defaultClientConfigModel.getAppId());
        nestBaseRequest.setSignature(apiRequestModel.getRequestSign());
        nestBaseRequest.setData(request);
        apiRequestModel.setRequest(nestBaseRequest);

        // 参数序列化
        String requestBody = paramSerializable.serializeObject(apiRequestModel, context);
        apiRequestModel.setRequestBody(requestBody);
        return apiRequestModel;
    }

     /**
      * 处理客户端信息
      *
      * @return
      */
    @Override
    protected ClientInfoModel getClientInfo() {
        ClientInfoModel clientInfoModel = new ClientInfoModel();
        clientInfoModel.setClientCode("fuiou-sdk");
        clientInfoModel.setClientCode("富友分账");
        return clientInfoModel;
    }

     @Override
     protected NestBaseResponse buildApiResponse(ApiResponseModel apiResponseModel, ApiRequestModel apiRequestModel, DefaultRequestContext requestContext) {
         // todo: 一般来说该方法需要完成以下事项
         // 1.  2. 请求参数填充  3. 请求加签  4. 参数反序列化

        return null;
     }

     @Override
    protected ApiResponseModel httpRequest(ApiRequestModel apiRequestModel, DefaultRequestContext requestContext) throws IOException {
        return httpRequestHandler.httpRequest(apiRequestModel, requestContext);
    }

    @Override
    public NestBaseResponse execute(NestBizRequest request, NestApiDefinitionEnum apiDefinition) throws FsApiException {
        return super.doExecute(request, apiDefinition);
    }
}

==> fshows-sdk-core-1.0.0.20231225-20240102.092826-10-sources.jar: com/fshows/sdk/core/client/tempalte/nest/NestTemplateApiClinet.java <==
/**
 * fshows.com
 * Copyright (C) 2013-2023 All Rights Reserved.
 */
package
        com.fshows.sdk.core.client.tempalte.nest;

import com.fshows.sdk.core.client.base.AbstractApiClient;
import com.fshows.sdk.core.client.base.handler.IHttpRequestHandler;
import com.fshows.sdk.core.client.base.model.ApiRequestModel;
import com.fshows.sdk.core.client.base.model.ApiResponseModel;
import com.fshows.sdk.core.client.base.model.ClientInfoModel;
import com.fshows.sdk.core.client.base.model.DefaultClientConfigModel;
import com.fshows.sdk.core.client.base.model.DefaultRequestContext;
import com.fshows.sdk.core.client.base.definition.IApiDefinition;
import com.fshows.sdk.core.client.base.handler.IApiSignHandler;
import com.fshows.sdk.core.client.base.handler.ISerializableHandler;
import com.fshows.sdk.core.client.component.http.PostHttpRequestHandler;
import com.fshows.sdk.core.client.tempalte.nest.apienum.NestApiDefinitionEnum;
import com.fshows.sdk.core.client.tempalte.nest.request.NestBaseRequest;
import com.fshows.sdk.core.client.tempalte.nest.request.NestBizRequest;
import com.fshows.sdk.core.client.tempalte.nest.response.NestBaseResponse;
import com.fshows.sdk.core.client.component.serializable.JsonSerializableHandler;
import com.fshows.sdk.core.client.component.signer.RsaSignHandlerImpl;
import com.fshows.sdk.core.exception.FsApiException;
import com.fshows.sdk.core.util.RequestParamUtils;

import java.io.IOException;

/**
 * 嵌套参数客户端模版
 * @author liluqing
 * @version NestTemplateApiClinet.java, v 0.1 2023-12-12 15:40
 */
public class NestTemplateApiClinet extends AbstractApiClient<NestBizRequest, NestBaseResponse, NestApiDefinitionEnum> {

     /**
      * 加签验签处理器
      */
    protected IApiSignHandler iApiSignHandler = new RsaSignHandlerImpl();

     /**
      * 序列化处理器
      */
     protected ISerializableHandler paramSerializable = new JsonSerializableHandler();

     /**
      * 请求执行器
      */
     protected IHttpRequestHandler httpRequestHandler = new PostHttpRequestHandler();

    public NestTemplateApiClinet(DefaultClientConfigModel apiClientConfig) throws FsApiException {
        super(apiClientConfig);
    }

     /**
      * 构建请求参数
      *
      * @param request
      * @param context
      * @return
      */
    @Override
    protected ApiRequestModel buildApiRequestModel(NestBizRequest request, DefaultRequestContext context) {
        // todo: 一般来说该方法需要完成以下事项
        // 1. 设置网关地址  2. 请求参数填充  3. 请求加签  4. 请求参数序列化

        // sdk客户端配置
        DefaultClientConfigModel defaultClientConfigModel = context.getApiClientConfig();

        ApiRequestModel apiRequestModel = new ApiRequestModel();
        // 设置网关地址
        apiRequestModel.setApiURL(context.getApiClientConfig().getApiParentURL() + context.getIApiDefinition().getApiURI());
        // 请求加签处理
        apiRequestModel.setParamMap(RequestParamUtils.toMapObj(request, apiClientConfig.isHump()));
        apiRequestModel.setRequestSign(iApiSignHandler.sign(apiRequestModel, context));

        // 补充参数构建实际的请求入参
        NestBaseRequest nestBaseRequest = new NestBaseRequest();
        nestBaseRequest.setMchntCd(defaultClientConfigModel.getAppId());
        nestBaseRequest.setSignature(apiRequestModel.getRequestSign());
        nestBaseRequest.setData(request);
        apiRequestModel.setRequest(nestBaseRequest);

        // 参数序列化
        String requestBody = paramSerializable.serializeObject(apiRequestModel, context);
        apiRequestModel.setRequestBody(requestBody);
        return apiRequestModel;
    }

     /**
      * 处理客户端信息
      *
      * @return
      */
    @Override
    protected ClientInfoModel getClientInfo() {
        ClientInfoModel clientInfoModel = new ClientInfoModel();
        clientInfoModel.setClientCode("fuiou-sdk");
        clientInfoModel.setClientCode("富友分账");
        return clientInfoModel;
    }

     @Override
     protected NestBaseResponse buildApiResponse(ApiResponseModel apiResponseModel, ApiRequestModel apiRequestModel, DefaultRequestContext requestContext) {
         // todo: 一般来说该方法需要完成以下事项
         // 1.  2. 请求参数填充  3. 请求加签  4. 参数反序列化

        return null;
     }

     @Override
    protected ApiResponseModel httpRequest(ApiRequestModel apiRequestModel, DefaultRequestContext requestContext) throws IOException {
        return httpRequestHandler.httpRequest(apiRequestModel, requestContext);
    }

    @Override
    public NestBaseResponse execute(NestBizRequest request, NestApiDefinitionEnum apiDefinition) throws FsApiException {
        return super.doExecute(request, apiDefinition);
    }

    @Override
    public NestBaseResponse execute(NestBizRequest request, NestApiDefinitionEnum apiDefinition, DefaultClientConfigModel configModel) throws FsApiException {
        return super.doExecute(request, apiDefinition, configModel);
    }
}
